@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.002'; # TRIAL VERSION
+our $VERSION = '0.003'; # TRIAL VERSION
 
 # Dependencies
 use 5.010;
@@ -54,8 +54,9 @@ has deviceIP => (
 
 
 has devicePort => (
-    is  => 'ro',
-    isa => 'Int',
+    is      => 'ro',
+    isa     => 'Int',
+    default => '9100',
 );
 
 
@@ -65,6 +66,13 @@ has baudrate => (
     default => 38400,
 );
 
+
+has serialOverUSB => (
+    is      => 'rw',
+    isa     => 'Bool',
+    default => '1',
+);
+
 has _driver => (
     is         => 'ro',
     lazy_build => 1,
@@ -88,6 +96,7 @@ sub _build__driver {
         return Printer::ESCPOS::Connections::Serial->new(
             deviceFilePath => $self->deviceFilePath,
             baudrate       => $self->baudrate,
+            serialOverUSB  => $self->serialOverUSB,
         );
     }
 }
@@ -126,7 +135,7 @@ Printer::ESCPOS - Interface for all thermal or dot-matrix receipt printers that
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -236,6 +245,10 @@ Contains the network port of the device when its a network printer. The module c
 
 When used as a local serial device you can set the baudrate of the printer too. Default (38400) will usually work, but not always. 
 
+=head2 serialOverUSB
+
+Set this value to 1 if you are connecting your printer using the USB Cable but it shows up as a serial device and you are using the 'Serial' driver.
+
 =head2 printer
 
 Use this attribute to send commands to the printer
