@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::Network;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.002'; # TRIAL VERSION
+our $VERSION = '0.003'; # TRIAL VERSION
 
 # Dependencies
 
@@ -32,8 +32,9 @@ has deviceIP => (
 
 
 has devicePort => (
-    is  => 'ro',
-    isa => 'Int',
+    is      => 'ro',
+    isa     => 'Int',
+    default => '9100',
 );
 
 has _connection => (
@@ -58,15 +59,31 @@ sub _build__connection {
 
 
 sub read {
-    my ( $self, $bytes ) = @_;
+    my ( $self, $question, $bytes ) = @_;
     my $data;
-    $bytes |= 1024;
+    $bytes ||= 2;
 
+    say unpack( "H*", $question );
+    $self->_connection->write($question);
     $self->_connection->read( $data, $bytes );
 
     return $data;
 }
 
+
+sub print {
+    my ( $self, $raw ) = @_;
+    my @chunks;
+    my $buffer = $self->_buffer;
+    my $n      = 64;               # Size of each chunk in bytes
+
+    @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
+    for my $chunk (@chunks) {
+        $self->_connection->write($chunk);
+    }
+    $self->_buffer('');
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -82,7 +99,7 @@ Printer::ESCPOS::Connections::Network - Network Connection Interface for Printer
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 ATTRIBUTES
 
@@ -100,6 +117,10 @@ Contains the network port of the device when its a network printer. The module c
 
 Read Data from the printer 
 
+=head2 print
+
+Sends buffer data to the printer.
+
 =head1 AUTHOR
 
 Shantanu Bhadoria (shantanu@cpan.org)
