@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::Serial;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.002'; # TRIAL VERSION
+our $VERSION = '0.003'; # TRIAL VERSION
 
 # Dependencies
 
@@ -23,6 +23,7 @@ with 'Printer::ESCPOS::Roles::Connection';
 use namespace::autoclean;
 
 use Device::SerialPort;
+use Time::HiRes qw(usleep);
 
 
 has deviceFilePath => (
@@ -44,6 +45,13 @@ has readConstTime => (
     default => 150,
 );
 
+
+has serialOverUSB => (
+    is      => 'rw',
+    isa     => 'Bool',
+    default => '0',
+);
+
 has _connection => (
     is         => 'ro',
     lazy_build => 1,
@@ -74,6 +82,28 @@ sub read {
     return $data;
 }
 
+
+sub print {
+    my ( $self, $raw ) = @_;
+    my @chunks;
+    my $buffer = $self->_buffer;
+    my $n      = 8;                # Size of each chunk in bytes
+    $n = 64 if ( $self->serialOverUSB );
+
+    @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
+    for my $chunk (@chunks) {
+        $self->_connection->write($chunk);
+        if ( $self->serialOverUSB ) {
+            $self->_connection->read();
+        }
+        else {
+            usleep(10000)
+              ; # Serial Port is annoying, it doesn't tell you when it is ready to get the next chunk
+        }
+    }
+    $self->_buffer('');
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -89,7 +119,7 @@ Printer::ESCPOS::Connections::Serial - Serial Connection Interface for Printer::
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 ATTRIBUTES
 
@@ -109,12 +139,20 @@ $printer = Printer::Thermal->new(deviceFilePath => '/dev/ttyACM0', baudrate => 9
 
 Seconds per unfulfilled read call, default 150 
 
+=head2 serialOverUSB
+
+Set this value to 1 if you are connecting your printer using the USB Cable but it shows up as a serial device
+
 =head1 METHODS
 
 =head2 read
 
 Read Data from the printer 
 
+=head2 print
+
+Sends buffer data to the printer.
+
 =head1 AUTHOR
 
 Shantanu Bhadoria (shantanu@cpan.org)
