@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.002'; # TRIAL VERSION
+our $VERSION = '0.003'; # TRIAL VERSION
 
 # Dependencies
 use 5.010;
@@ -59,9 +59,6 @@ sub printAreaWidth {
     $params{nL} = defined $params{nL} ? $params{nL} : 65;
     $params{nH} = defined $params{nH} ? $params{nH} : 2;
 
-    say $params{nL};
-    say $params{nH};
-
     $self->lf();
     $self->driver->write( _GS . 'W' . chr( $params{nL} ) . chr( $params{nH} ) );
 }
@@ -465,7 +462,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for Printer::E
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 METHODS
 
